
The computer program CALFEM is written for the software MATLAB and is an interactive tool for learning the finite element method. CALFEM is an abbreviation of ”Computer Aided Learning of the Finite Element Method” and been developed by the Division of Structural Mechanics at Lund University since the late 70’s.

Unlike MATLAB, which have expensive licenses, Python is free to use and distribute both for personal and commercial use. An implementation to Py